@@ -224,7 +224,7 @@ func TestFirewalls_Get(t *testing.T) {
 	urlStr = path.Join(urlStr, fID)
 
 	mux.HandleFunc(urlStr, func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, "GET")
+		testMethod(t, r, http.MethodGet)
 		fmt.Fprint(w, firewallJSONResponse)
 	})
 
@@ -333,7 +333,7 @@ func TestFirewalls_Create(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "POST")
+		testMethod(t, r, http.MethodPost)
 		if !reflect.DeepEqual(v, expectedFirewallRequest) {
 			t.Errorf("Request body = %+v, expected %+v", v, expectedFirewallRequest)
 		}
@@ -481,7 +481,7 @@ func TestFirewalls_Delete(t *testing.T) {
 	fID := "fe6b88f2-b42b-4bf7-bbd3-5ae20208f0b0"
 	urlStr = path.Join(urlStr, fID)
 	mux.HandleFunc(urlStr, func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, "DELETE")
+		testMethod(t, r, http.MethodDelete)
 	})
 
 	_, err := client.Firewalls.Delete(ctx, fID)
@@ -496,11 +496,11 @@ func TestFirewalls_List(t *testing.T) {
 	defer teardown()
 
 	mux.HandleFunc("/v2/firewalls", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, "GET")
+		testMethod(t, r, http.MethodGet)
 		fmt.Fprint(w, firewallListJSONResponse)
 	})
 
-	actualFirewalls, _, err := client.Firewalls.List(ctx, nil)
+	actualFirewalls, resp, err := client.Firewalls.List(ctx, nil)
 
 	if err != nil {
 		t.Errorf("Firewalls.List returned error: %v", err)
@@ -508,7 +508,11 @@ func TestFirewalls_List(t *testing.T) {
 
 	expectedFirewalls := makeExpectedFirewalls()
 	if !reflect.DeepEqual(actualFirewalls, expectedFirewalls) {
-		t.Errorf("Firewalls.List returned %+v, expected %+v", actualFirewalls, expectedFirewalls)
+		t.Errorf("Firewalls.List returned firewalls %+v, expected %+v", actualFirewalls, expectedFirewalls)
+	}
+	expectedMeta := &Meta{Total: 1}
+	if !reflect.DeepEqual(resp.Meta, expectedMeta) {
+		t.Errorf("Firewalls.List returned meta %+v, expected %+v", resp.Meta, expectedMeta)
 	}
 }
 
@@ -517,11 +521,11 @@ func TestFirewalls_ListByDroplet(t *testing.T) {
 	defer teardown()
 
 	mux.HandleFunc("/v2/droplets/123/firewalls", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, "GET")
+		testMethod(t, r, http.MethodGet)
 		fmt.Fprint(w, firewallListJSONResponse)
 	})
 
-	actualFirewalls, _, err := client.Firewalls.ListByDroplet(ctx, 123, nil)
+	actualFirewalls, resp, err := client.Firewalls.ListByDroplet(ctx, 123, nil)
 
 	if err != nil {
 		t.Errorf("Firewalls.List returned error: %v", err)
@@ -529,7 +533,11 @@ func TestFirewalls_ListByDroplet(t *testing.T) {
 
 	expectedFirewalls := makeExpectedFirewalls()
 	if !reflect.DeepEqual(actualFirewalls, expectedFirewalls) {
-		t.Errorf("Firewalls.List returned %+v, expected %+v", actualFirewalls, expectedFirewalls)
+		t.Errorf("Firewalls.List returned firewalls %+v, expected %+v", actualFirewalls, expectedFirewalls)
+	}
+	expectedMeta := &Meta{Total: 1}
+	if !reflect.DeepEqual(resp.Meta, expectedMeta) {
+		t.Errorf("Firewalls.List returned meta %+v, expected %+v", resp.Meta, expectedMeta)
 	}
 }
 
@@ -550,7 +558,7 @@ func TestFirewalls_AddDroplets(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "POST")
+		testMethod(t, r, http.MethodPost)
 		if !reflect.DeepEqual(v, dRequest) {
 			t.Errorf("Request body = %+v, expected %+v", v, dRequest)
 		}
@@ -589,7 +597,7 @@ func TestFirewalls_RemoveDroplets(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "DELETE")
+		testMethod(t, r, http.MethodDelete)
 		if !reflect.DeepEqual(v, dRequest) {
 			t.Errorf("Request body = %+v, expected %+v", v, dRequest)
 		}
@@ -628,7 +636,7 @@ func TestFirewalls_AddTags(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "POST")
+		testMethod(t, r, http.MethodPost)
 		if !reflect.DeepEqual(v, tRequest) {
 			t.Errorf("Request body = %+v, expected %+v", v, tRequest)
 		}
@@ -666,7 +674,7 @@ func TestFirewalls_RemoveTags(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "DELETE")
+		testMethod(t, r, http.MethodDelete)
 		if !reflect.DeepEqual(v, tRequest) {
 			t.Errorf("Request body = %+v, expected %+v", v, tRequest)
 		}
@@ -721,7 +729,7 @@ func TestFirewalls_AddRules(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "POST")
+		testMethod(t, r, http.MethodPost)
 		if !reflect.DeepEqual(v, rr) {
 			t.Errorf("Request body = %+v, expected %+v", v, rr)
 		}
@@ -776,7 +784,7 @@ func TestFirewalls_RemoveRules(t *testing.T) {
 			t.Fatal(err)
 		}
 
-		testMethod(t, r, "DELETE")
+		testMethod(t, r, http.MethodDelete)
 		if !reflect.DeepEqual(v, rr) {
 			t.Errorf("Request body = %+v, expected %+v", v, rr)
 		}
